@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 
-'''
+"""
 This module implements Compatibility corrections for mixing runs of different
 functionals.
-'''
+"""
 
 from __future__ import division
 
@@ -56,13 +56,13 @@ class Compatibility(EntryPostProcessor):
         self._config.readfp(open(os.path.join(module_dir,
                                               "Compatibility.cfg")))
         u_corrections = {}
-        for el in self.input_set.incar_settings['LDAUU'].keys():
-            name = '{}{}UCorrections{}'.format(input_set_name, compat_type, el)
+        for el in self.input_set.incar_settings["LDAUU"].keys():
+            name = "{}{}UCorrections{}".format(input_set_name, compat_type, el)
             if name in self._config.sections():
                 corr = dict(self._config.items(name))
                 u_corrections[el] = {k: float(v) for k, v in corr.items()}
 
-        cpd_energies = dict(self._config.items('{}{}CompoundEnergies'
+        cpd_energies = dict(self._config.items("{}{}CompoundEnergies"
                                                .format(input_set_name,
                                                        compat_type)))
 
@@ -70,13 +70,23 @@ class Compatibility(EntryPostProcessor):
         self._cpd_energies = {k: float(v) for k, v in cpd_energies.items()}
 
         self._valid_potcars = set(self.input_set.potcar_settings.values())
-        self._u_settings = self.input_set.incar_settings['LDAUU']
+        self._u_settings = self.input_set.incar_settings["LDAUU"]
 
         if compat_type == "GGA":
             self._u_corrections = {}
             self._u_settings = {}
 
     def requires_hubbard(self, comp):
+        """
+        Check if a particular composition requies U parameters to be set.
+
+        Args:
+            comp:
+                Composition
+
+        Returns:
+            True if hubbard U parameter required. False otherwise.
+        """
         comp = Composition(comp)
         elements = sorted([el for el in comp.elements if comp[el] > 0],
                               key=lambda el: el.X)
@@ -98,19 +108,19 @@ class Compatibility(EntryPostProcessor):
             An adjusted entry if entry is compatible, otherwise None is
             returned.
         """
-        if entry.parameters.get('run_type', 'GGA') == "HF":
+        if entry.parameters.get("run_type", "GGA") == "HF":
             return None
 
         ucorr = self._u_corrections
         cpdenergies = self._cpd_energies
-        calc_u = entry.parameters['hubbards']
+        calc_u = entry.parameters["hubbards"]
         calc_u = defaultdict(int) if calc_u == None else calc_u
         comp = entry.composition
         #Check that POTCARs are valid
         rform = comp.reduced_formula
         if rform not in cpdenergies:
             psp_settings = set([sym.split(" ")[1]
-                                for sym in entry.parameters['potcar_symbols']])
+                                for sym in entry.parameters["potcar_symbols"]])
             if not self._valid_potcars.issuperset(psp_settings):
                 return None
 
