@@ -18,7 +18,7 @@ import re
 import os
 
 from pymatgen.io.vaspio import Vasprun, Poscar
-from pymatgen.io.cifio import CifParser
+from pymatgen.io.cifio import CifParser, CifWriter
 from pymatgen.io.cssrio import Cssr
 
 
@@ -41,10 +41,37 @@ def read_structure(filename):
     elif lower_filename.startswith("poscar") \
             or lower_filename.startswith("contcar"):
         return Poscar.from_file(filename, False).structure
-    elif re.search("vasprun.*\.xml.*", lower_filename):
+    elif re.search("vasprun", lower_filename) \
+            and re.search("xml", lower_filename):
         return Vasprun(filename).final_structure
     elif re.search("\.cssr", lower_filename):
         cssr = Cssr.from_file(filename)
         return cssr.structure
 
     raise ValueError("Unrecognized file extension!")
+
+
+def write_structure(structure, filename):
+    """
+    Write a structure to a file based on file extension. For example, anything
+    ending in a "cif" is assumed to be a Crystallographic Information Format
+    file.
+
+    Args:
+        structure:
+            Structure to write
+        filename:
+            A filename to write to.
+    """
+    lower_filename = os.path.basename(filename).lower()
+    if re.search("\.cif", lower_filename):
+        writer = CifWriter(structure)
+    elif lower_filename.startswith("poscar") \
+            or lower_filename.startswith("contcar"):
+        writer = Poscar(structure)
+    elif re.search("\.cssr", lower_filename):
+        writer = Cssr(structure)
+    else:
+        raise ValueError("Unrecognized file extension!")
+
+    writer.write_file(filename)
